@@ -56,7 +56,35 @@ REPORT_TRANSLATIONS ={
     
     'Phases hours (last 7 days)': {
         'en': 'Phases hours (last 7 days)'
-    }
+    },
+    'Molds used':{
+         'en': 'Molds used'
+    },
+    'Mold name':{
+         'en': 'Mold name'
+    }, 
+    'Time on':{
+         'en': 'Time on'
+    },
+    'Original cycle':{
+         'en': 'Original cycle'
+    },
+    'Average cycle':{
+         'en': 'Average cycle'
+    }, 
+    'KPI syncro':{
+         'en': 'KPI syncro'
+    },
+    'KPI standard':{
+         'en': 'KPI standard'
+    },
+    'Recipes':{
+         'en': 'Recipes'
+    },
+    'Recipe name':{
+         'en': 'Recipe name'
+    },
+
 }
 
 
